@@ -3,61 +3,15 @@
 package processor
 
 import (
+	"io"
+	"os"
+	"slices"
 	"strings"
 	"testing"
 
 	"github.com/mattn/go-runewidth"
 )
 
-func TestPrintTrace(t *testing.T) {
-	Trace = true
-	printTrace("Testing print trace")
-	Trace = false
-	printTrace("Testing print trace")
-}
-
-func TestPrintDebug(t *testing.T) {
-	Debug = true
-	printDebug("Testing print debug")
-	Debug = false
-	printDebug("Testing print debug")
-}
-
-func TestPrintWarn(t *testing.T) {
-	Verbose = true
-	printWarn("Testing print warn")
-	Verbose = false
-	printWarn("Testing print warn")
-}
-
-func TestPrintError(t *testing.T) {
-	printError("Testing print error")
-}
-
-func TestPrintWarnF(t *testing.T) {
-	printWarnf("Testing print error")
-}
-
-func TestPrintDebugF(t *testing.T) {
-	printDebugf("Testing print error")
-}
-
-func TestPrintTraceF(t *testing.T) {
-	printTracef("Testing print error")
-}
-
-func TestGetFormattedTime(t *testing.T) {
-	res := getFormattedTime()
-
-	if !strings.Contains(res, "T") {
-		t.Error("String does not contain expected T", res)
-	}
-
-	if !strings.Contains(res, "Z") {
-		t.Error("String does not contain expected Z", res)
-	}
-}
-
 func TestCalculateCocomo(t *testing.T) {
 	var str strings.Builder
 	calculateCocomo(1, &str)
@@ -359,6 +313,54 @@ func TestSortLanguageSummaryComplexity(t *testing.T) {
 	}
 }
 
+func TestSortLanguageSummaryBytes(t *testing.T) {
+	SortBy = "bytes"
+	ls := []LanguageSummary{
+		{
+			Name:  "a",
+			Bytes: 1,
+		},
+		{
+			Name:  "b",
+			Bytes: 1,
+		},
+		{
+			Name:  "c",
+			Bytes: 2,
+		},
+	}
+
+	ls = sortLanguageSummary(ls)
+
+	if ls[0].Name != "c" || ls[1].Name != "a" {
+		t.Error("Expected c to be first and a second")
+	}
+}
+
+func TestSortLanguageSummaryFiles(t *testing.T) {
+	SortBy = "files"
+	ls := []LanguageSummary{
+		{
+			Name:  "a",
+			Count: 1,
+		},
+		{
+			Name:  "b",
+			Count: 1,
+		},
+		{
+			Name:  "c",
+			Count: 2,
+		},
+	}
+
+	ls = sortLanguageSummary(ls)
+
+	if ls[0].Name != "c" || ls[1].Name != "a" {
+		t.Error("Expected c to be first and a second")
+	}
+}
+
 func TestSortSummaryNames(t *testing.T) {
 	SortBy = "name"
 	ls := []LanguageSummary{
@@ -1372,6 +1374,34 @@ func TestToHTML(t *testing.T) {
 	if !strings.Contains(res, `<html lang="en">`) {
 		t.Error("Expected to have HTML wrapper")
 	}
+
+	if !strings.Contains(res, "<th>Language</th>") {
+		t.Error("html Language check failed")
+	}
+	if !strings.Contains(res, "<th>Files</th>") {
+		t.Error("html Files check failed")
+	}
+	if !strings.Contains(res, "<th>Lines</th>") {
+		t.Error("html Lines check failed")
+	}
+	if !strings.Contains(res, "<th>Blank</th>") {
+		t.Error("html Blank check failed")
+	}
+	if !strings.Contains(res, "<th>Comment</th>") {
+		t.Error("html Comment check failed")
+	}
+	if !strings.Contains(res, "<th>Code</th>") {
+		t.Error("html Code check failed")
+	}
+	if !strings.Contains(res, "<th>Complexity</th>") {
+		t.Error("html Complexity check failed")
+	}
+	if !strings.Contains(res, "<th>Bytes</th>") {
+		t.Error("html Bytes check failed")
+	}
+	if !strings.Contains(res, "<th>Uloc</th>") {
+		t.Error("html Uloc check failed")
+	}
 }
 
 func TestToHTMLTable(t *testing.T) {
@@ -1405,8 +1435,8 @@ func TestToHTMLTable(t *testing.T) {
 func TestUnicodeAwareTrimAscii(t *testing.T) {
 	tmp := "aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa.md"
 	res := unicodeAwareTrim(tmp, shortFormatFileTruncate)
-	if res != "~aaaaaaaaaaaaaaaaaaaaaaaaaa.md" {
-		t.Error("expected ~aaaaaaaaaaaaaaaaaaaaaaaaaa.md got", res)
+	if res != "~aaaaaaaaaaaaaaaaaaaaaaa.md" {
+		t.Error("expected ~aaaaaaaaaaaaaaaaaaaaaaa.md got", res)
 	}
 }
 
@@ -1421,8 +1451,8 @@ func TestUnicodeAwareTrimExactSizeAscii(t *testing.T) {
 func TestUnicodeAwareTrimUnicode(t *testing.T) {
 	tmp := "中文中文中文中文中文中文中文中文中文中文中文中文中文中文中文中文.md"
 	res := unicodeAwareTrim(tmp, shortFormatFileTruncate)
-	if res != "~文中文中文中文中文中文中文.md" {
-		t.Error("expected ~文中文中文中文中文中文中文.md got", res)
+	if res != "~文中文中文中文中文中文.md" {
+		t.Error("expected ~文中文中文中文中文中文.md got", res)
 	}
 }
 
@@ -1456,9 +1486,312 @@ func BenchmarkFileSummerize(b *testing.B) {
 			Language:   "Go",
 			Lines:      10,
 		}
+		fileSummaryJobQueue <- &FileJob{
+			Blank:      2,
+			Bytes:      2,
+			Code:       2,
+			Comment:    2,
+			Complexity: 2,
+			Language:   "Python",
+			Lines:      20,
+		}
 		close(fileSummaryJobQueue)
 		b.StartTimer()
 
 		fileSummarize(fileSummaryJobQueue)
 	}
 }
+
+func TestGetCSVFilesSortFunc(t *testing.T) {
+	records := [][]string{
+		// Language,Provider,Filename,Lines,Code,Comments,Blanks,Complexity,Bytes,ULOC
+		{"Go", "/path/to/file", "go.go", "10", "10", "0", "1", "1", "1024", "0"},
+		{"Python", "/path/to/file", "python.py", "20", "20", "1", "2", "2", "2048", "0"},
+		{"C#", "/path/to/file", "csharp.cs", "30", "30", "2", "3", "3", "4096", "0"},
+		{"C++", "/path/to/file", "cpp.cpp", "40", "40", "3", "4", "4", "8192", "0"},
+	}
+	testCases := []struct {
+		sortBy   string
+		expected []string
+	}{
+		{
+			sortBy:   "names",
+			expected: []string{"C++", "C#", "Go", "Python"},
+		},
+		{
+			sortBy:   "langs",
+			expected: []string{"C#", "C++", "Go", "Python"},
+		},
+		{
+			sortBy:   "lines",
+			expected: []string{"C++", "C#", "Python", "Go"},
+		},
+		{
+			sortBy:   "code",
+			expected: []string{"C++", "C#", "Python", "Go"},
+		},
+		{
+			sortBy:   "comments",
+			expected: []string{"C++", "C#", "Python", "Go"},
+		},
+		{
+			sortBy:   "blanks",
+			expected: []string{"C++", "C#", "Python", "Go"},
+		},
+		{
+			sortBy:   "complexity",
+			expected: []string{"C++", "C#", "Python", "Go"},
+		},
+		{
+			sortBy:   "bytes",
+			expected: []string{"C++", "C#", "Python", "Go"},
+		},
+		{
+			sortBy:   "default",
+			expected: []string{"C++", "C#", "Go", "Python"},
+		},
+	}
+	for _, tc := range testCases {
+		data := slices.Clone(records) // always use an unordered records
+		slices.SortFunc(data, getCSVFilesSortFunc(tc.sortBy))
+		sortedRecords := make([]string, 0, len(data))
+		for i := range data {
+			sortedRecords = append(sortedRecords, data[i][0])
+		}
+		if !slices.Equal(sortedRecords, tc.expected) {
+			t.Errorf("sortBy: %s failed, expected: %v, got: %v", tc.sortBy, tc.expected, sortedRecords)
+		}
+	}
+}
+
+func TestToCSVFilesHeader(t *testing.T) {
+	inputChan := make(chan *FileJob, 1000)
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "bbbb.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "aaaa.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	close(inputChan)
+	res := toCSVFiles(inputChan)
+	header, _, _ := strings.Cut(res, "\n")
+	const expected = "Language,Provider,Filename,Lines,Code,Comments,Blanks,Complexity,Bytes,ULOC"
+	if header != expected {
+		t.Errorf("check toCSVFiles header failed, expected: %v, got: %v", expected, header)
+	}
+}
+
+func TestToCSVStreamHeader(t *testing.T) {
+	inputChan := make(chan *FileJob, 1000)
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "bbbb.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "aaaa.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	close(inputChan)
+
+	originStdout := os.Stdout
+	t.Cleanup(func() {
+		os.Stdout = originStdout
+	})
+	r, w, err := os.Pipe()
+	if err != nil {
+		t.Fatal(err)
+	}
+	os.Stdout = w
+	go func() {
+		toCSVStream(inputChan)
+		_ = w.Close()
+	}()
+	output, err := io.ReadAll(r)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	header, _, _ := strings.Cut(string(output), "\n")
+	const expected = "Language,Provider,Filename,Lines,Code,Comments,Blanks,Complexity,Bytes,Uloc"
+	if header != expected {
+		t.Errorf("check toCSVStream header failed, expected: %v, got: %v", expected, header)
+	}
+}
+
+func TestToJSONKeys(t *testing.T) {
+	inputChan := make(chan *FileJob, 1000)
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "bbbb.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "aaaa.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	close(inputChan)
+
+	res := toJSON(inputChan)
+	if !strings.Contains(res, `"Name":`) {
+		t.Error("JSON Name check failed")
+	}
+	if !strings.Contains(res, `"Files":`) {
+		t.Error("JSON Files check failed")
+	}
+	if !strings.Contains(res, `"Lines":`) {
+		t.Error("JSON Lines check failed")
+	}
+	if !strings.Contains(res, `"Blank":`) {
+		t.Error("JSON Blank check failed")
+	}
+	if !strings.Contains(res, `"Comment":`) {
+		t.Error("JSON Comment check failed")
+	}
+	if !strings.Contains(res, `"Code":`) {
+		t.Error("JSON Code check failed")
+	}
+	if !strings.Contains(res, `"Complexity":`) {
+		t.Error("JSON Complexity check failed")
+	}
+	if !strings.Contains(res, `"Bytes":`) {
+		t.Error("JSON Bytes check failed")
+	}
+	if !strings.Contains(res, `"ULOC":`) {
+		t.Error("JSON Uloc check failed")
+	}
+}
+
+func TestToJSON2Keys(t *testing.T) {
+	inputChan := make(chan *FileJob, 1000)
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "bbbb.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	inputChan <- &FileJob{
+		Language:           "Go",
+		Filename:           "aaaa.go",
+		Extension:          "go",
+		Location:           "./",
+		Bytes:              1000,
+		Lines:              1000,
+		Code:               1000,
+		Comment:            1000,
+		Blank:              1000,
+		Complexity:         1000,
+		WeightedComplexity: 1000,
+		Binary:             false,
+	}
+	close(inputChan)
+
+	res := toJSON2(inputChan)
+	if !strings.Contains(res, `"Name":`) {
+		t.Error("JSON2 Name check failed")
+	}
+	if !strings.Contains(res, `"Files":`) {
+		t.Error("JSON2 Files check failed")
+	}
+	if !strings.Contains(res, `"Lines":`) {
+		t.Error("JSON2 Lines check failed")
+	}
+	if !strings.Contains(res, `"Blank":`) {
+		t.Error("JSON2 Blank check failed")
+	}
+	if !strings.Contains(res, `"Comment":`) {
+		t.Error("JSON2 Comment check failed")
+	}
+	if !strings.Contains(res, `"Code":`) {
+		t.Error("JSON2 Code check failed")
+	}
+	if !strings.Contains(res, `"Complexity":`) {
+		t.Error("JSON2 Complexity check failed")
+	}
+	if !strings.Contains(res, `"Bytes":`) {
+		t.Error("JSON2 Bytes check failed")
+	}
+	if !strings.Contains(res, `"ULOC":`) {
+		t.Error("JSON2 Uloc check failed")
+	}
+	if !strings.Contains(res, `"languageSummary":`) {
+		t.Error("JSON2 languageSummary check failed")
+	}
+	if !strings.Contains(res, `"estimatedCost":`) {
+		t.Error("JSON2 estimatedCost check failed")
+	}
+	if !strings.Contains(res, `"estimatedScheduleMonths":`) {
+		t.Error("JSON2 estimatedScheduleMonths check failed")
+	}
+	if !strings.Contains(res, `"estimatedPeople":`) {
+		t.Error("JSON2 estimatedPeople check failed")
+	}
+}
