@@ -4,7 +4,6 @@ package processor
 
 import (
 	"bytes"
-	"fmt"
 	"hash"
 	"runtime/debug"
 	"strings"
@@ -22,7 +21,7 @@ const (
 	SCommentCode       int64 = 4 // Indicates comment after code
 	SMulticomment      int64 = 5
 	SMulticommentCode  int64 = 6 // Indicates multi comment after code
-	SMulticommentBlank int64 = 7 // Indicates multi comment ended with blank afterwards
+	SMulticommentBlank int64 = 7 // Indicates multi comment ended with blank afterward
 	SString            int64 = 8
 	SDocString         int64 = 9
 )
@@ -100,11 +99,12 @@ func shouldProcess(currentByte, processBytesMask byte) bool {
 }
 
 func resetState(currentState int64) int64 {
-	if currentState == SMulticomment || currentState == SMulticommentCode {
+	switch currentState {
+	case SMulticomment, SMulticommentCode:
 		currentState = SMulticomment
-	} else if currentState == SString {
+	case SString:
 		currentState = SString
-	} else {
+	default:
 		currentState = SBlank
 	}
 
@@ -173,16 +173,12 @@ func docStringState(fileJob *FileJob, index int, endPoint int, stringTrie *Trie,
 				// the index
 				for j := index + len(endString); j <= endPoint; j++ {
 					if fileJob.Content[j] == '\n' {
-						if Debug {
-							printDebug("Found newline so docstring is comment")
-						}
+						printDebug("Found newline so docstring is comment")
 						return i, SComment
 					}
 
 					if !isWhitespace(fileJob.Content[j]) {
-						if Debug {
-							printDebug(fmt.Sprintf("Found something not whitespace so is code: %s", string(fileJob.Content[j])))
-						}
+						printDebugF("Found something not whitespace so is code: %s", string(fileJob.Content[j]))
 						return i, SCode
 					}
 				}
@@ -263,6 +259,7 @@ func codeState(
 			case TComplexity:
 				if index == 0 || isWhitespace(fileJob.Content[index-1]) {
 					fileJob.Complexity++
+					fileJob.ComplexityLine[len(fileJob.ComplexityLine)-1] = fileJob.ComplexityLine[len(fileJob.ComplexityLine)-1] + 1
 				}
 			}
 		}
@@ -351,6 +348,7 @@ func blankState(
 		currentState = SCode
 		if index == 0 || isWhitespace(fileJob.Content[index-1]) {
 			fileJob.Complexity++
+			fileJob.ComplexityLine[len(fileJob.ComplexityLine)-1] = fileJob.ComplexityLine[len(fileJob.ComplexityLine)-1] + 1
 		}
 
 	default:
@@ -436,6 +434,7 @@ func CountStats(fileJob *FileJob) {
 
 	// TODO needs to be set via langFeatures.Quotes[0].IgnoreEscape for the matching feature
 	ignoreEscape := false
+	fileJob.ComplexityLine = append(fileJob.ComplexityLine, 0)
 
 	for index := checkBomSkip(fileJob); index < int(fileJob.Bytes); index++ {
 		// Based on our current state determine if the state should change by checking
@@ -503,6 +502,7 @@ func CountStats(fileJob *FileJob) {
 		// we are currently in
 		if fileJob.Content[index] == '\n' || index >= endPoint {
 			fileJob.Lines++
+			fileJob.ComplexityLine = append(fileJob.ComplexityLine, 0)
 
 			if NoLarge && fileJob.Lines >= LargeLineCount {
 				// Save memory by unsetting the content as we no longer require it
@@ -520,7 +520,8 @@ func CountStats(fileJob *FileJob) {
 					}
 				}
 				if Trace {
-					printTrace(fmt.Sprintf("%s line %d ended with state: %d: counted as code", fileJob.Location, fileJob.Lines, currentState))
+					// Don't remove the outside if-statements, for performance
+					printTraceF("%s line %d ended with state: %d: counted as code", fileJob.Location, fileJob.Lines, currentState)
 				}
 			case SComment, SMulticomment, SMulticommentBlank:
 				fileJob.Comment++
@@ -531,7 +532,8 @@ func CountStats(fileJob *FileJob) {
 					}
 				}
 				if Trace {
-					printTrace(fmt.Sprintf("%s line %d ended with state: %d: counted as comment", fileJob.Location, fileJob.Lines, currentState))
+					// Same as above
+					printTraceF("%s line %d ended with state: %d: counted as comment", fileJob.Location, fileJob.Lines, currentState)
 				}
 			case SBlank:
 				fileJob.Blank++
@@ -541,7 +543,8 @@ func CountStats(fileJob *FileJob) {
 					}
 				}
 				if Trace {
-					printTrace(fmt.Sprintf("%s line %d ended with state: %d: counted as blank", fileJob.Location, fileJob.Lines, currentState))
+					// Same as above
+					printTraceF("%s line %d ended with state: %d: counted as blank", fileJob.Location, fileJob.Lines, currentState)
 				}
 			case SDocString:
 				fileJob.Comment++
@@ -551,7 +554,8 @@ func CountStats(fileJob *FileJob) {
 					}
 				}
 				if Trace {
-					printTrace(fmt.Sprintf("%s line %d ended with state: %d: counted as comment", fileJob.Location, fileJob.Lines, currentState))
+					// Same as above
+					printTraceF("%s line %d ended with state: %d: counted as comment", fileJob.Location, fileJob.Lines, currentState)
 				}
 			}
 		}
@@ -559,14 +563,14 @@ func CountStats(fileJob *FileJob) {
 
 	if UlocMode && Files {
 		uloc := map[string]struct{}{}
-		for _, l := range strings.Split(string(fileJob.Content), "\n") {
+		for l := range strings.SplitSeq(strings.TrimRight(string(fileJob.Content), "\n"), "\n") {
 			uloc[l] = struct{}{}
 		}
 		fileJob.Uloc = len(uloc)
 	}
 
 	if MaxMean {
-		for _, l := range strings.Split(string(fileJob.Content), "\n") {
+		for l := range strings.SplitSeq(strings.TrimRight(string(fileJob.Content), "\n"), "\n") {
 			fileJob.LineLength = append(fileJob.LineLength, len(l))
 		}
 	}
@@ -584,11 +588,7 @@ func CountStats(fileJob *FileJob) {
 				fileJob.Generated = true
 				fileJob.Language = fileJob.Language + " (gen)"
 				isGenerated = true
-
-				if Verbose {
-					printWarn(fmt.Sprintf("%s identified as isGenerated with heading comment", fileJob.Filename))
-				}
-
+				printWarnF("%s identified as isGenerated with heading comment", fileJob.Filename)
 				break
 			}
 		}
@@ -599,20 +599,17 @@ func CountStats(fileJob *FileJob) {
 		avgLineByteCount := len(fileJob.Content) / int(fileJob.Lines)
 		minifiedGeneratedCheck(avgLineByteCount, fileJob)
 	}
+
+	fileJob.ComplexityLine = fileJob.ComplexityLine[:fileJob.Lines]
 }
 
 func minifiedGeneratedCheck(avgLineByteCount int, fileJob *FileJob) {
 	if avgLineByteCount >= MinifiedGeneratedLineByteLength {
 		fileJob.Minified = true
 		fileJob.Language = fileJob.Language + " (min)"
-
-		if Verbose {
-			printWarn(fmt.Sprintf("%s identified as minified/generated with average line byte length of %d >= %d", fileJob.Filename, avgLineByteCount, MinifiedGeneratedLineByteLength))
-		}
+		printWarnF("%s identified as minified/generated with average line byte length of %d >= %d", fileJob.Filename, avgLineByteCount, MinifiedGeneratedLineByteLength)
 	} else {
-		if Debug {
-			printDebug(fmt.Sprintf("%s not identified as minified/generated with average line byte length of %d < %d", fileJob.Filename, avgLineByteCount, MinifiedGeneratedLineByteLength))
-		}
+		printDebugF("%s not identified as minified/generated with average line byte length of %d < %d", fileJob.Filename, avgLineByteCount, MinifiedGeneratedLineByteLength)
 	}
 }
 
@@ -621,9 +618,7 @@ func checkBomSkip(fileJob *FileJob) int {
 	// UTF-8 BOM which if detected we should skip the BOM as we can then count correctly
 	// []byte is UTF-8 BOM taken from https://en.wikipedia.org/wiki/Byte_order_mark#Byte_order_marks_by_encoding
 	if bytes.HasPrefix(fileJob.Content, []byte{239, 187, 191}) {
-		if Verbose {
-			printWarn(fmt.Sprintf("UTF-8 BOM found for file %s skipping 3 bytes", fileJob.Filename))
-		}
+		printWarnF("UTF-8 BOM found for file %s skipping 3 bytes", fileJob.Filename)
 		return 3
 	}
 
@@ -631,7 +626,7 @@ func checkBomSkip(fileJob *FileJob) int {
 	if Verbose {
 		for _, v := range ByteOrderMarks {
 			if bytes.HasPrefix(fileJob.Content, v) {
-				printWarn(fmt.Sprintf("BOM found for file %s indicating it is not ASCII/UTF-8 and may be counted incorrectly or ignored as a binary file", fileJob.Filename))
+				printWarnF("BOM found for file %s indicating it is not ASCII/UTF-8 and may be counted incorrectly or ignored as a binary file", fileJob.Filename)
 			}
 		}
 	}
@@ -667,14 +662,10 @@ func fileProcessorWorker(input chan *FileJob, output chan *FileJob) {
 				if atomic.LoadInt64(&gcEnabled) == 0 && atomic.LoadInt64(&fileCount) >= int64(GcFileCount) {
 					debug.SetGCPercent(gcPercent)
 					atomic.AddInt64(&gcEnabled, 1)
-					if Verbose {
-						printWarn("read file limit exceeded GC re-enabled")
-					}
+					printWarn("read file limit exceeded GC re-enabled")
 				}
 
-				if Trace {
-					printTrace(fmt.Sprintf("nanoseconds read into memory: %s: %d", job.Location, makeTimestampNano()-fileStartTime))
-				}
+				printTraceF("nanoseconds read into memory: %s: %d", job.Location, makeTimestampNano()-fileStartTime)
 
 				if err == nil {
 					job.Content = content
@@ -682,9 +673,7 @@ func fileProcessorWorker(input chan *FileJob, output chan *FileJob) {
 						output <- job
 					}
 				} else {
-					if Verbose {
-						printWarn(fmt.Sprintf("error reading: %s %s", job.Location, err))
-					}
+					printWarnF("error reading: %s %s", job.Location, err)
 				}
 			}
 
@@ -696,9 +685,7 @@ func fileProcessorWorker(input chan *FileJob, output chan *FileJob) {
 		wg.Wait()
 		close(output)
 
-		if Debug {
-			printDebug(fmt.Sprintf("milliseconds reading files into memory: %d", makeTimestampMilli()-startTime))
-		}
+		printDebugF("milliseconds reading files into memory: %d", makeTimestampMilli()-startTime)
 	}()
 }
 
@@ -734,15 +721,11 @@ func processFile(job *FileJob) bool {
 
 			lang, err := DetectSheBang(string(contents[:cutoff]))
 			if err != nil {
-				if Verbose {
-					printWarn(fmt.Sprintf("unable to determine #! language for %s", job.Location))
-				}
+				printWarnF("unable to determine #! language for %s", job.Location)
 				return false
 			}
-			if Verbose {
-				printWarn(fmt.Sprintf("detected #! %s for %s", lang, job.Location))
-			}
 
+			printWarnF("detected #! %s for %s", lang, job.Location)
 			job.Language = lang
 			LoadLanguageFeature(lang)
 		}
@@ -754,10 +737,7 @@ func processFile(job *FileJob) bool {
 		duplicates.mux.Lock()
 		jobHash := job.Hash.Sum(nil)
 		if duplicates.Check(job.Bytes, jobHash) {
-			if Verbose {
-				printWarn(fmt.Sprintf("skipping duplicate file: %s", job.Location))
-			}
-
+			printWarnF("skipping duplicate file: %s", job.Location)
 			duplicates.mux.Unlock()
 			return false
 		}
@@ -767,34 +747,24 @@ func processFile(job *FileJob) bool {
 	}
 
 	if IgnoreMinified && job.Minified {
-		if Verbose {
-			printWarn(fmt.Sprintf("skipping minified file: %s", job.Location))
-		}
+		printWarnF("skipping minified file: %s", job.Location)
 		return false
 	}
 
 	if IgnoreGenerated && job.Generated {
-		if Verbose {
-			printWarn(fmt.Sprintf("skipping generated file: %s", job.Location))
-		}
+		printWarnF("skipping generated file: %s", job.Location)
 		return false
 	}
 
 	if NoLarge && job.Lines >= LargeLineCount {
-		if Verbose {
-			printWarn(fmt.Sprintf("skipping large file due to line length: %s", job.Location))
-		}
+		printWarnF("skipping large file due to line length: %s", job.Location)
 		return false
 	}
 
-	if Trace {
-		printTrace(fmt.Sprintf("nanoseconds process: %s: %d", job.Location, makeTimestampNano()-fileStartTime))
-	}
+	printTraceF("nanoseconds process: %s: %d", job.Location, makeTimestampNano()-fileStartTime)
 
 	if job.Binary {
-		if Verbose {
-			printWarn(fmt.Sprintf("skipping file identified as binary: %s", job.Location))
-		}
+		printWarnF("skipping file identified as binary: %s", job.Location)
 		return false
 	}
 
@@ -802,7 +772,8 @@ func processFile(job *FileJob) bool {
 	// avoiding inflating the counts
 	if UlocMode {
 		ulocMutex.Lock()
-		for _, l := range strings.Split(string(job.Content), "\n") {
+
+		for l := range strings.SplitSeq(strings.TrimRight(string(job.Content), "\n"), "\n") {
 			ulocGlobalCount[l] = struct{}{}
 
 			_, ok := ulocLanguageCount[job.Language]
@@ -819,7 +790,7 @@ func processFile(job *FileJob) bool {
 
 func hardRemapLanguage(job *FileJob) bool {
 	remapped := false
-	for _, s := range strings.Split(RemapAll, ",") {
+	for s := range strings.SplitSeq(RemapAll, ",") {
 		t := strings.Split(s, ":")
 		if len(t) == 2 {
 			cutoff := 1000 // 1000 bytes into the file to look
@@ -832,10 +803,7 @@ func hardRemapLanguage(job *FileJob) bool {
 			if strings.Contains(string(job.Content[:cutoff]), t[0]) {
 				job.Language = t[1]
 				remapped = true
-
-				if Verbose {
-					printWarn(fmt.Sprintf("hard remapping: %s to %s", job.Location, job.Language))
-				}
+				printWarnF("hard remapping: %s to %s", job.Location, job.Language)
 			}
 		}
 	}
@@ -845,7 +813,7 @@ func hardRemapLanguage(job *FileJob) bool {
 
 func unknownRemapLanguage(job *FileJob) bool {
 	remapped := false
-	for _, s := range strings.Split(RemapUnknown, ",") {
+	for s := range strings.SplitSeq(RemapUnknown, ",") {
 		t := strings.Split(s, ":")
 		if len(t) == 2 {
 			cutoff := 1000 // 1000 bytes into the file to look
@@ -856,10 +824,7 @@ func unknownRemapLanguage(job *FileJob) bool {
 			}
 
 			if strings.Contains(string(job.Content[:cutoff]), t[0]) {
-				if Verbose {
-					printWarn(fmt.Sprintf("unknown remapping: %s to %s", job.Location, job.Language))
-				}
-
+				printWarnF("unknown remapping: %s to %s", job.Location, job.Language)
 				job.Language = t[1]
 				remapped = true
 			}
