@@ -470,7 +470,7 @@ else
     exit
 fi
 
-if ./scc ./examples/minified/ -i js -z --no-scc-ignore | grep -q "JavaScript (min)"; then
+if ./scc ./examples/minified/ -i js -z --no-scc-ignore | grep -q "JavaScript (mi"; then
     echo -e "${GREEN}PASSED flagged as min"
 else
     echo -e "${RED}======================================================="
@@ -614,33 +614,6 @@ else
     exit
 fi
 
-if ./scc -f csv | grep -q "Bytes"; then
-    echo -e "${GREEN}PASSED csv bytes check"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED csv bytes check"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
-if ./scc -f csv-stream | grep -q "Bytes"; then
-    echo -e "${GREEN}PASSED csv-stream bytes check"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED csv-stream bytes check"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
-if ./scc -f html | grep -q "Bytes"; then
-    echo -e "${GREEN}PASSED html bytes check"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED html bytes check"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
 if ./scc -f json | grep -q "Bytes"; then
     echo -e "${GREEN}PASSED json bytes check"
 else
@@ -650,24 +623,6 @@ else
     exit
 fi
 
-if ./scc -f json  -a | grep -q "ULOC"; then
-    echo -e "${GREEN}PASSED json uloc check"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED json uloc check"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
-if ./scc -f json2 | grep -q "Bytes"; then
-    echo -e "${GREEN}PASSED json2 bytes check"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED json bytes check"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
 if ./scc | grep -q "megabytes"; then
     echo -e "${GREEN}PASSED bytes check"
 else
@@ -677,24 +632,6 @@ else
     exit
 fi
 
-if ./scc -f csv | grep -q "Language,Lines,Code,Comments,Blanks,Complexity,Bytes,Files,ULOC"; then
-    echo -e "${GREEN}PASSED csv summary"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED csv summary"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
-if ./scc -f csv --by-file | grep -q "Language,Provider,Filename,Lines,Code,Comments,Blanks,Complexity,Bytes"; then
-    echo -e "${GREEN}PASSED csv file"
-else
-    echo -e "${RED}======================================================="
-    echo -e "FAILED csv file"
-    echo -e "=======================================================${NC}"
-    exit
-fi
-
 if ./scc --by-file --format-multi "tabular:stdout,html:stdout,csv:stdout" | grep -q "Language,Provider"; then
     echo -e "${GREEN}PASSED format multi check"
 else
@@ -918,16 +855,20 @@ fi
 specificLanguages=(
     'ABNF '
     'Alchemist '
+    'Algol 68 '
     'Alloy '
+    'ArkTs '
     'Arturo '
     'Astro '
     'AWK '
     'BASH '
     'Bean '
     'Bicep '
-    'Bitbucket Pipeline '
+    'Bitbucket Pipe'
+    'Blueprint '
     'Boo '
     'Bosque '
+    'C3 '
     'C Shell '
     'C# '
     'Cairo '
@@ -936,12 +877,16 @@ specificLanguages=(
     'Circom '
     'Clipper '
     'Clojure '
+    'CMake '
     'Cuda '
+    'Cypher '
+    'D2 '
     'DAML '
     'DM '
     'Docker ignore '
     'Dockerfile '
     'DOT '
+    'Elixir Template'
     'Elm '
     'EmiT '
     'F# '
@@ -953,8 +898,10 @@ specificLanguages=(
     'Gemfile '
     'Gleam '
     'Go '
+    'Go+ '
     'Godot Scene '
     'GraphQL '
+    'Gremlin '
     'Gwion '
     'HAML '
     'Hare '
@@ -962,14 +909,19 @@ specificLanguages=(
     'ignore '
     'INI '
     'Java '
+    'JavaScript '
+    'JCL '
     'JSON5 '
     'JSONC '
     'jq '
     'Korn Shell '
+    'Koto '
     'LALRPOP '
     'License '
     'LiveScript '
     'LLVM IR '
+    'Lua '
+    'Luau '
     'Luna '
     'Makefile '
     'Metal '
@@ -977,13 +929,22 @@ specificLanguages=(
     'Moonbit '
     'Nushell '
     'OpenQASM '
+    'OpenTofu '
+    'Perl '
     'Pkl '
+    'POML '
+    'PostScript '
     'Proto '
+    'Python '
     'Q# '
     'R '
     'Racket '
     'Rakefile '
+    'RAML '
     'Redscript '
+    'Rich Text Form'
+    'Scallop '
+    'Seed7 '
     'Shell '
     'Sieve '
     'Slang '
@@ -991,11 +952,14 @@ specificLanguages=(
     'Smalltalk '
     'Snakemake '
     'Stan '
+    'Systemd '
+    'Tact '
     'Teal '
     'Tera '
     'Templ '
     'Terraform '
     'TTCN-3 '
+    'TypeScript '
     'TypeSpec '
     'Typst '
     'Up '
@@ -1003,6 +967,7 @@ specificLanguages=(
     'Web Services '
     'wenyan '
     'Wren '
+    'XMake '
     'XML Schema '
     'YAML '
     'Yarn '
@@ -1010,9 +975,10 @@ specificLanguages=(
     'ZoKrates '
     'Zsh '
 )
+SPECIFIC_LANG_TEST_RESULT=$(./scc "examples/language/" --no-scc-ignore)
 for i in "${specificLanguages[@]}"
 do
-    if ./scc "examples/language/" --no-scc-ignore | grep -q "$i"; then
+    if echo "$SPECIFIC_LANG_TEST_RESULT" | grep -q "$i"; then
         echo -e "${GREEN}PASSED $i Language Check"
     else
         echo -e "${RED}======================================================="
@@ -1136,8 +1102,43 @@ else
     echo -e "${GREEN}PASSED Issue564 Regression Check"
 fi
 
+# Regression issue https://github.com/boyter/scc/issues/610
+Issue610Line=$(./scc -f csv "examples/issue610/" --no-scc-ignore | grep 'TypeScript' | cut -d ',' -f 2)
+Issue610Code=$(./scc -f csv "examples/issue610/" --no-scc-ignore | grep 'TypeScript' | cut -d ',' -f 3)
+Issue610Comments=$(./scc -f csv "examples/issue610/" --no-scc-ignore | grep 'TypeScript' | cut -d ',' -f 4)
+Issue610Blanks=$(./scc -f csv "examples/issue610/" --no-scc-ignore | grep 'TypeScript' | cut -d ',' -f 5)
+Issue610Complexity=$(./scc -f csv "examples/issue610/" --no-scc-ignore | grep 'TypeScript' | cut -d ',' -f 6)
+if [ $Issue610Line -ne 11 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue610 line counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue610Code -ne 7 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue610 code counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue610Comments -ne 2 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue610 comments counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue610Blanks -ne 2 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue610 blanks counting"
+    echo -e "=======================================================${NC}"
+    exit
+elif [ $Issue610Complexity -ne 1 ] ; then
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Issue610 complexity counting"
+    echo -e "=======================================================${NC}"
+    exit
+else
+    echo -e "${GREEN}PASSED Issue610 Regression Check"
+fi
+
 # Extra case for longer languages that are normally truncated
-for i in 'CloudFormation (YAM' 'CloudFormation (JSO'
+for i in 'CloudFormation' 'CloudFormation'
 do
     if ./scc "examples/language/" --no-scc-ignore | grep -q "$i"; then
         echo -e "${GREEN}PASSED $i Language Check"
@@ -1149,6 +1150,30 @@ do
     fi
 done
 
+if [[ "$(./scc --farmat 2>&1 | grep -A 1 'The most similar flag of --farmat is:' | tail -n 1)" == $'\t--format' ]]; then
+    echo -e "${GREEN}PASSED signle flag suggestion test"
+else
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Should suggest --format $i"
+    echo -e "=======================================================${NC}"
+    exit
+fi
+if [[ "$(./scc --no-gignore 2>&1 | grep -A 2 'The most similar flags of --no-gignore are:' | tail -n 2 | head -n 1)" == $'\t--no-ignore' ]]; then
+    if [[ "$(./scc --no-gignore 2>&1 | grep -A 2 'The most similar flags of --no-gignore are:' | tail -n 1)" == $'\t--no-gitignore' ]]; then
+        echo -e "${GREEN}PASSED multiple flags suggestion test"
+    else
+        echo -e "${RED}======================================================="
+        echo -e "FAILED Should suggest --no-gitignore $i"
+        echo -e "=======================================================${NC}"
+        exit
+    fi
+else
+    echo -e "${RED}======================================================="
+    echo -e "FAILED Should suggest --no-ignore $i"
+    echo -e "=======================================================${NC}"
+    exit
+fi
+
 echo -e  "${NC}Checking compile targets..."
 
 echo "   darwin..."
